import { Component, OnInit } from '@angular/core';
import { ActivatedRoute } from '@angular/router';
import { Recipe } from '../models/recipe';
import { IngredientRecipe } from '../models/ingredient-recipe';
import { CommonModule } from '@angular/common';
import { MatButtonModule } from '@angular/material/button';
import { MatCardModule } from '@angular/material/card';

@Component({
  selector: 'app-recipe',
  standalone: true,
  imports: [CommonModule, MatButtonModule, MatCardModule],
  templateUrl: './recipe.component.html',
  styleUrls: ['./recipe.component.scss'],
})
export class RecipeComponent implements OnInit {
  recipe: Recipe | undefined;
  ingredientRecipes: IngredientRecipe[] = [];

  constructor(private route: ActivatedRoute) {}

  ngOnInit(): void {
    const recipeId = this.route.snapshot.paramMap.get('id');
    const recipes: Recipe[] = JSON.parse(
      localStorage.getItem('recipes') || '[]'
    );
    this.recipe = recipes.find((r) => r.id.toString() === recipeId);

    if (this.recipe) {
      this.ingredientRecipes = this.getIngredientRecipes(this.recipe.id);
    }
  }

  getIngredientRecipes(recipeId: number): IngredientRecipe[] {
    const ingredientRecipes: IngredientRecipe[] = JSON.parse(
      localStorage.getItem('ingredientRecipes') || '[]'
    );
    return ingredientRecipes.filter((ir) => ir.idRecipe === recipeId);
  }

  getIngredientQuantity(ingredientId: number): number {
    const ingredientRecipe = this.ingredientRecipes.find(
      (ir) => ir.idIngredient === ingredientId
    );
    return ingredientRecipe ? ingredientRecipe.quantity : 0;
  }

  navBack(): void {
    window.history.back();
  }
}
